<!-- !split -->
<!-- jupyter-book 06_02_testdoc.md -->
# Project: References to [demo:ex:2](04_04_testdoc.html#demo:ex:2) in a heading works for pandoc

<div id="exer:you"></div>
file=selc_composed.pdf

Refer to the previous exercise as [Exercise: Make references to projects and problems](06_01_testdoc.html#exer:some:formula),
the two before that as [demo:ex:2](04_04_testdoc.html#demo:ex:2) and [Project: Explore Distributions of Random Circles](proj:circle1.html#proj:circle1),
and this one as [Project: References to Project [demo:ex:2](04_04_testdoc.html#demo:ex:2) in a heading works for pandoc](#exer:you).

